@@ -136,6 +136,9 @@ class DAG(collections.abc.Mapping):
         # task access differ using .dag.differ
         self.differ = self._params.differ
 
+        self.serializer = None
+        self.unserializer = None
+
     @property
     def executor(self):
         return self._executor
@@ -239,10 +242,18 @@ class DAG(collections.abc.Mapping):
 
     def render(self, force=False, show_progress=True):
         """
-
         Render resolves all placeholders in tasks and determines whether
         a task should run or not based on the task.product metadata, this
         allows up-to-date tasks to be skipped.
+
+        Parameters
+        ----------
+        force
+            Ignore product metadata status and prepare all tasks to be
+            executed. This option renders much faster in DAGs with products
+            whose metadata is stored in remote systems, because there is no
+            need to fetch metadata over the network. If the DAG won't be
+            built, this option is recommended.
         """
         g = self._to_graph()
 
@@ -516,8 +527,7 @@ class DAG(collections.abc.Mapping):
 
         self.render()
 
-        return Table(
-            [self._G.nodes[name]['task'].status(**kwargs) for name in self._G])
+        return Table([self[name].status(**kwargs) for name in self])
 
     def to_dict(self, include_plot=False):
         """Returns a dict representation of the dag's Tasks,
@@ -582,7 +592,13 @@ class DAG(collections.abc.Mapping):
 
         return out
 
-    @requires(['pygraphviz'])
+    @requires(
+        ['pygraphviz'],
+        extra_msg=(
+            'Beware that "graphviz" (which is not pip-installable) is a '
+            'dependency of "pygraphviz", the easiest way to install both is '
+            'through conda "conda install pygraphviz", for more options see: '
+            'https://graphviz.org/'))
     def plot(self, output='tmp'):
         """Plot the DAG
         """
@@ -686,6 +702,12 @@ class DAG(collections.abc.Mapping):
         upstream = self._G.predecessors(task_name)
         return {u: self._G.nodes[u]['task'] for u in upstream}
 
+    def get_downstream(self, task_name):
+        """
+        Get downstream tasks for a given task name
+        """
+        return list(self._G.successors(task_name))
+
     def _clear_cached_status(self):
         # NOTE: maybe make this a context manager and/or a decorator
         self._logger.debug('Clearing product status')
@@ -704,13 +726,30 @@ class DAG(collections.abc.Mapping):
         return self._G.remove_node(key)
 
     def __iter__(self):
-        """Iterate task names in topological order
+        """
+        Iterate task names in topological order. Topological order is
+        desirable in many situations, this order guarantees that for any given
+        task, its dependencies are executed first, but it's also useful for
+        other purposes, such as listing tasks, because it shows a more natural
+        order to see how data flows start to finish. For cases where this
+        sorting is not required, used the DAG._iter() method instead.
+
+
+        Notes
+        -----
+        https://en.wikipedia.org/wiki/Topological_sorting
         """
         # TODO: raise a warning if this any of this dag tasks have tasks
         # from other tasks as dependencies (they won't show up here)
         for name in nx.algorithms.topological_sort(self._G):
             yield name
 
+    def _iter(self):
+        """Iterate over tasks names (unordered but more efficient than __iter__
+        """
+        for name in self._G:
+            yield name
+
     def __len__(self):
         return len(self._G)
 
