@@ -8,7 +8,7 @@ class ProductsContainer:
     An iterator that when initialized with a sequence behaves just like it
     but when initialized with a mapping, iterates over values (instead of
     keys), this non-standard behavior but it is needed to simpplify the
-    MetaProduct API
+    MetaProduct API since it has to work with lists and dictionaries
     """
 
     def __init__(self, products):
@@ -127,9 +127,6 @@ class MetaProduct:
         for p in self.products:
             p.render(params, **kwargs)
 
-    def _short_repr(self):
-        return ', '.join([p._short_repr() for p in self.products])
-
     def __repr__(self):
         return '{}: {}'.format(type(self).__name__, str(self.products))
 
@@ -143,5 +140,11 @@ class MetaProduct:
     def __getitem__(self, key):
         return self.products[key]
 
+    def get(self, key):
+        try:
+            return self[key]
+        except KeyError:
+            return None
+
     def __len__(self):
         return len(self.products)
