@@ -1,14 +1,14 @@
-from copy import copy
+import copy as copy_module
 from collections import abc
 
 
 class Params(abc.Mapping):
     """
     Read-only mapping to represent params passed in Task constructor. It
-    initializes with a copy of the passed dictionary. Cannot be initialized
-    with a key "upstream" nor "product" as they are added upon Task rendering
+    initializes with a copy of the passed dictionary. It verifies that the
+    dictionary does not have a key "upstream" nor "product" because they'd
+    clash with the ones added upon Task rendering
     """
-
     def __init__(self, params=None):
         if params is None:
             self._dict = {}
@@ -23,18 +23,37 @@ class Params(abc.Mapping):
                                  '"product" key as it automatically added '
                                  'upon rendering')
 
-            self._dict = copy(params)
+            self._dict = copy_module.copy(params)
+
+    @classmethod
+    def _from_dict(cls, params, copy=True):
+        """
+        Private API for initializing Params objects with arbitrary dictionary
+        """
+        obj = cls(params=None)
+
+        if copy:
+            obj._dict = copy_module.copy(params)
+        else:
+            obj._dict = params
+
+        return obj
+
+    def _setitem(self, key, value):
+        """Private method for updating the underlying data
+        """
+        self._dict[key] = value
 
     def to_dict(self):
-        return copy(self._dict)
+        return copy_module.copy(self._dict)
 
     def __getitem__(self, key):
         try:
             return self._dict[key]
         except KeyError:
             raise KeyError('Cannot obtain Task param named '
-                           '"{}", declared params are: {}'
-                           .format(key, list(self._dict.keys())))
+                           '"{}", declared params are: {}'.format(
+                               key, list(self._dict.keys())))
 
     def __setitem__(self, key, value):
         raise RuntimeError('Task params are read-only, if you need a copy'
